__version__ = '1.0.5'
__author__ = 'Shubham Sharma'
__email__ = 'shubhamjsharma10@gmail.com'
__description__ = 'A simple and convinient way to send emails in python'

__license__ = "Apache License, Version 2.0"
__copyright__ = "2020 %s" % __author__